@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.230480;
+package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.230680;
 
 # ABSTRACT: Generate valid CPAN::Changes Changelogs from git
 
@@ -205,10 +205,10 @@ sub _get_tags {
     my @tags;
     foreach my $tag ($self->_git->RUN('tag')) {
         next unless $tag =~ $self->tag_regexp;
-        push @tags, $tag;
+        push @tags, [ version->parse($1), $tag ];
     }
 
-    @{$self->_tags} = sort { version->parse($a) <=> version->parse($b) } @tags;
+    @{$self->_tags} = map { $_->[1] } sort { $a->[0] <=> $b->[0] } @tags;
     push @{$self->_tags}, 'HEAD';
     return;
 }
@@ -404,7 +404,7 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Generate valid CPAN::Chan
 
 =head1 VERSION
 
-version 0.230480
+version 0.230680
 
 =head1 SYNOPSIS
 
